(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     45429,       1649]*)
(*NotebookOutlinePosition[     46887,       1693]*)
(*  CellTagsIndexPosition[     46843,       1689]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(BASIC\ AVF\ OPERATIONS\),
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell["\<\
(*This Notebook can be stepped through manually, or executed all at \
once by Evaluate Initialization and then scrolled through.  Because it \
frequently uses \"%\" to reference prior output, it will not execute properly \
with Evaluate Notebook.  Near the end, Mathematica may beep once for an \
ignorable warning.  Printing the notebook can serve as a reference for AVF \
operations and syntax. Any existing Kernel should be Quit before starting. \
Running time: < 1 min.*)
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*INTRODUCING\ THE\ FUNDAMENTAL\ LISTS\ OF\ \(VARIABLES.\)*) \)\)],
   "Input"],

Cell[BoxData[
    \(makescalars[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A look at the \"dscalars\" list which is automatically created:*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell["(*These exact 1-forms are also included in \"forms\".*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell["\<\
(*To add in some non-exact basis 1-forms with derivative symbols in \
\"dforms\":*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeforms[{\[Xi], \[Eta], \[Zeta]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dforms\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The members of \"dforms\" are exact 2-forms which can be given \
additional properties using \"drules\". The sub-section on \"drules\" appears \
below.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*AVF initializes the \"elements\" list and the \"algebra\" matrix \
as follows:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(algebra\)], "Input",
  InitializationCell->True],

Cell["\<\
(*so it is ready to accomplish ordinary differential form analysis \
without further input. 
Since that case is treated simply as a special (trivial) algebra, all the \
commands for it
are identical to the more general case with a non-trivial algebra to be used \
here.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeelements[{m\_0, m\_1, m\_2, m\_3}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The three lists, \"scalars\", \"forms\", and \"elements\", may be \
introduced in any order and be changed at any time by executing new \"make\" \
commands. Note that AVF needs to be told that something is a variable (not \
constant) by being included in \"scalars\" or \"forms\", but not what it \
depends on. In fact, the members of these fundamental lists are always \
treated as independent variables, and can neither be functions nor have \
assigned values. Interdependence among them may be imposed by using \
replacement rules, however. See below.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*",
  StyleBox["Establishing the Algebra Table",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The next statement defines the multiplication table of a \
2-dimensional Clifford algebra, which is isomorphic to the algebra of real 2\
\[Times]2 orthogonal matrices. Flipping a few of the signs would turn it into \
the quaternion algebra, H.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(M\_2[
        R] = {elements, {m\_1, m\_0, m\_3, m\_2}, {m\_2, \(-m\_3\), 
          m\_0, \(-m\_1\)}, {m\_3, \(-m\_2\), m\_1, \(-m\_0\)}}\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The \"makealgebra\" command sets the reserved variable \"algebra\" to \
its argument, ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "[R],*) "
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makealgebra[M\_2[R]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(algebra\)], "Input",
  InitializationCell->True],

Cell["(*and this outputs the active algebra table as a matrix.*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  PageBreakAbove->False,
  InitializationCell->True],

Cell["\<\
(*The command, mtx[], is just an abbreviation for Mathematica's \
MatrixForm[] and will accept the same arguments. \"algebra\" is the default \
argument.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*",
  StyleBox["Matrix Representations",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "(*Calculations in AVF are accomplished using the algebra table for \
products of elements. Sometimes it is useful to have a matrix representation \
of the elements, even though the program never requires it. For example, a \
matrix representation of the ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "[R] generators is given by :*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(\(mat\_0 = {{1, 0}, {0, 1}};\)\), "\n", 
    \(\(mat\_1 = {{1, 0}, {0, \(-1\)}};\)\), "\n", 
    \(\(mat\_2 = {{0, \(-1\)}, {\(-1\), 0}};\)\), "\n", 
    \(\(mat\_3 = {{0, \(-1\)}, {1, 0}};\)\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and their matrix products agree with the ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "[R] algebra table; e.g. ,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((mat\_1)\) . mat\_2 == mat\_3\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Since the indices of \"mat\" and \"m\" agree,  any AVF expression \
or list can be converted to matrix form by the kernel replacement rule, { /. \
m -> mat }; i.e. ,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(elements /. m -> mat\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Another example is shown below, and the use of matrices is \
developed further in other Demos .*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n\n (*SAMPLE\ INPUT\ EXPRESSIONS*) \)\)], "Input",
  PageBreakAbove->True],

Cell["\<\
(*Here are two sample AVF expressions. The first, avf1, is an AVF \
1-form; the second, avf2, has a different kind of factor omitted from each \
term and is a differential form of inhomogeneous degree. The \"scalars\" and \
\"forms\" lists are output for reference.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf1 = 2  \[Lambda]\ y\ \[Zeta]\ m\_2\  + m\_3\ x\^3\ dz\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(avf2 = z\ m\_2 + 3\ \[Eta]\ y + m\_1\ dx\[Wedge]\[Xi]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(scalars\), "\n", 
    \(forms\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The missing algebra element in the second input term of avf2 defaults to \
the identity, ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  ". It never needs to be typed in input, and is generally suppressed in \
output. Note that, except inside a wedge product, the order of factors within \
a term is immaterial.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(\n\)\(\n\)\( (*ALGEBRAIC\ OPERATIONS*) \)\)\)], "Input"],

Cell[TextData[{
  "(*",
  StyleBox["Multiplication",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The multiply operator, ** , simultaneously implements the \
Grassmann algebra of differential forms and the specified element algebra. \
Operator ** has high precedence; its multiplicands will need parentheses if \
they're not single names, and also in multiple products if the algebra is \
non-associative.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "(*A first example using ordinary differential forms, where ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  " is the implicit algebra element:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((x\ dy - y\ dx)\) ** \((\[Xi] - \[Eta])\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Though avf1 is a 1-form, its algebra-valued self product is \
non-zero:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf1 ** avf1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(avf3 = avf1 ** avf2\)], "Input",
  InitializationCell->True],

Cell["\<\
(*For this matrix algebra, AVF multiplication is associative, but \
generally non-commutative.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf1 ** avf3 ** 
        avf2 == \((avf1 ** avf1)\) ** \((avf2 ** avf2)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(avf1 ** avf2 =!= avf2 ** avf1\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["Formatting commands",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The non-zero coefficients of the algebra elements in an AVF \
expression are given as a list of differential forms by:*)\
\>", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(coeffs[avf3]\)], "Input",
  InitializationCell->True],

Cell["(*and the expression is displayed in collected form by:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[avf3]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*This is the only AVF command that always outputs the identity element ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  "explicitly. It is required in the next statement to give the correct \
matrix representation of avf3:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(matavf3 = collect[avf3] /. m -> mat\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[matavf3]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The collect[] command can be applied to arrays of AVFs, but \
coeffs[] must be Mapped onto them,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[{avf1, avf2}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Map[coeffs, {avf1, avf2}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["Vector",
    FontVariations->{"Underline"->True}],
  " ",
  StyleBox["Contraction",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell["\<\
(*The infix contraction operator is the small open circle, typed by \
the sequence, (esc, s , c , esc). It is used to contract a vector either on a \
single AVF, or on a list of them. Whenever new 1-forms are defined, the \
\"makeforms\" command automatically generates four independent vectors (vec1, \
vec2, vec3, vec4) just for convenience. Each vector is a symbol list of the \
same length as the \"forms\" list. The first two vectors:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec2\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Since they are expressed in the dual basis to \"forms\", each \
component of a vector is its contraction on the corresponding member of \
\"forms\"; i.e. ,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec1\[SmallCircle]\((\[Eta] + dz)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(avf2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec1\[SmallCircle]avf2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec1\[SmallCircle]%\)], "Input",
  InitializationCell->True],

Cell["(*A number of sequential contractions,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec2\[SmallCircle]vec1\[SmallCircle]avf3\)], "Input",
  InitializationCell->True],

Cell["(*and contraction on a list,*)", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(vec2\[SmallCircle]vec3\[SmallCircle]{avf1, avf2, avf3}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec3\[SmallCircle]%\)], "Input",
  InitializationCell->True],

Cell["\<\
(*It is not necessary to use these convenience vectors. Any list of \
scalar variables, including specified or unspecified functions of \"scalars\" \
may be used, so long as the list agrees in length with the \"forms\" list. \
Any such list will be interpreted as a vector expressed in the dual basis to \
\"forms\". Components not in \"scalars\"(or functions thereof) will be \
constant parameters, as are the convenience-vector components.*)\
\>", "Input",\

  FontFamily->"Times"],

Cell["\<\
(*A quick way to get a new vector of the correct length is by using \
kernel replacement,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(pvec = vec1 /. v1 -> p\)], "Input",
  InitializationCell->True],

Cell["(*or by the Mathematica command,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(pvec = Array[p, fmdim]\)], "Input",
  InitializationCell->True],

Cell[" (*where the reserved variable \"fmdim\" = Length[forms].*)", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*",
  StyleBox["Factoring an AVF",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf3\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Any basis form in \"forms\" or \"dforms\" will be factored out \
(to the left) of an AVF by:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(fac = factor[\[Zeta], avf3]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*All terms containing \[Zeta] are factored, so the following expression \
represents the part of avf3 that is actually independent of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  ":*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf3 - \[Zeta]\[Wedge]fac\)], "Input",
  InitializationCell->True],

Cell["\<\
(*This will simplify using the \"expand\" operator (lower case \
\"e\"), which is similar to Mathematica's upper case \"Expand\", except that \
it operates on wedge products .*)  \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*An iterative subroutine to factor out any monomial product of \
basis forms from an AVF would be:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(monomialfactor[mono_, avf_] := 
      Block[{fac}, \((fac = avf; 
          If[Head[mono] =!= Wedge, fac = factor[mono, fac], 
            Do[fac = factor[mono[\([i]\)], fac], {i, Length[mono]}]]; 
          fac)\)]\)], "Input",
  InitializationCell->True],

Cell["(*For example;*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(monomialfactor[\[Xi]\[Wedge]dx, avf3]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["The ",
    FontVariations->{"Underline"->True}],
  Cell[BoxData[
      \(TraditionalForm\`"\<expand\>"\)],
    FontVariations->{"Underline"->True}],
  StyleBox[" function",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The AVF function \"expand[expression]\" replaces all wedge \
products in \"expression\" with the actual multiplication operator, ** , and \
so re-calculates the entire expression. Any expression containing wedge \
products of AVF expressions can be expanded in this way. For \
instance,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf1\[Wedge]avf2\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Only the substitutions occurred because wedge is not recognized \
as an operator, and with the factors being algebra-valued-forms, it is a \
slight abuse of notation. Nevertheless, this re-derives avf3,*)\
\>", "Input",\

  FontFamily->"Times"],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note that an expression containing wedge products of factors \
which are not simple basis forms, such as avf1\[Wedge]avf2, is not an \
acceptable input for any AVF operations other than \"expand\". The operator \
\"expand\" must be used to convert such expressions to correct input form for \
other AVF functions.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Since every wedge product at all levels in the expressions will \
be calculated anew, using \"expand\"
allows arbitrary replacements to be made within wedge products, and this is \
its primary function. For example, the \[Zeta]-independent part of avf3 could \
also be obtained by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf3 /. \[Zeta] -> 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
Clearly, any wedge product in an input expression (even between \
basis forms) could just as well be typed using **. This has little real \
effect when used between basis forms (except perhaps to simplify and re-order \
a product into Mathematica's canonical order), but it constitutes a much \
larger abuse of standard nomenclature.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Xi]\[Wedge]dz + \[Eta]\[Wedge]\[Zeta]\[Wedge]\[Eta]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Xi] ** dz + \[Eta] ** \[Zeta] ** \[Eta]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\n\)\(\n\)\( (*EXTERIOR\ CALCULUS\ OPERATIONS*) \)\)\)], "Input"],

Cell["\<\
(*The exterior derivative of an AVF is given by \"d[expression]\"; \
e.g. ,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[avf1]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note that \"scalars\" and \"forms\" are differentiated, but the \
algebra elements and parameter \[Lambda] are not. A more complicated example \
is:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[avf3]\)], "Input",
  InitializationCell->True],

Cell["(*The operator, d[] , also works on a list of AVF's,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[{avf1, avf2}]\)], "Input",
  InitializationCell->True],

Cell["(*as well as on a matrix of them,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[matavf3]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The non-commutativity coming from both the Grassmann and the \
element algebras generally forbids any simple application of the Leibnitz \
rule for derivations, unless the leading factors are of homogeneous degree as \
differential forms and the algebraic order of the factors is preserved. The \
following expansion works because avf1 is a 1-form (note the minus sign).*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[avf1 ** avf2] == d[avf1] ** avf2 - avf1 ** d[avf2]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*For simplicity, the input samples, avf1 and avf2, involved only algebraic \
functions of the scalars. Any functions known to Mathematica can be used in \
an AVF, but any arguments not appearing in the \"scalars\" list will be \
treated as constant parameters;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(avf4 = \ Cos[k\ y] \[Xi]\ m\_1 + Sin[k\ y] \[Eta]\ m\_2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[avf4]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[avf4 ** avf4]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell["(*and an unspecified function including a parameter gives,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[f[x, y, z, k]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n\n(*",
  StyleBox["Defining \"drules\"",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*An important feature of AVF involves the list of replacement \
rules for exterior derivatives called \"drules\". Their primary purpose is to \
establish properties for the derivatives of the non-exact basis forms (the \
members of \"dforms\") which can then be easily implemented in AVF \
expressions. They are not restricted to such replacements, however, and may \
include any other appropriate replacement rules.
                             
Additional structure for the derivatives in \"dforms\" is prescribed by \
defining a set of replacement rules which are given by expansions of the \
members of \"dforms\" in terms of the members of \"forms\". If all the \
non-exact 1-forms are closed, for example, the appropriate value for \"drules\
\" is the reserved variable \"natural\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(natural\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and this is the default value of \"drules\" established initially \
for all the non-exact members of \"forms\" introduced by the \"makeforms\" \
command; i.e., currently,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["(*A different set of replacements can be defined; e.g.,*)", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(newdrules = {d\[Xi] -> \[Eta]\[Wedge]\[Zeta], 
        d\[Eta] -> \[Zeta]\[Wedge]\[Xi], 
        d\[Zeta] -> \[Xi]\[Wedge]\[Eta]}\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and this becomes the reserved variable \"drules\" using the \
\"makedrules\" command;*)\
\>", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[newdrules]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The current \"drules\" can be implemented in any AVF expression \
with the command \"applydrules\", which is defined by: applydrules[arg_] :=  \
expand[arg/.drules ]; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[avf2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(applydrules[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The \"drules\" can be changed at any time to a different set. As \
with other \"make\" commands, \"makedrules\" won't accumulate replacements, \
but different sets of rules may be combined using Join in the argument. The \
following command simply resets \"drules\" to \"natural\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[{}]\)], "Input",
  InitializationCell->True],

Cell["(*so that now,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(applydrules[d[avf2]]\)], "Input",
  InitializationCell->True],

Cell["(*Re-establish \"newdrules\".*)", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[newdrules]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The nested command just above,  applydrules[d[arg]] , is actually \
used more often than d[arg] alone. An abbreviated differentiation operator \
\"da[arg]\" is defined for it; i.e.,*)\
\>", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(d[\[Xi] + \[Eta]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(applydrules[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[\[Xi] + \[Eta]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Note that in using da[], differentiation occurs ",
  StyleBox["before",
    FontVariations->{"Underline"->True}],
  " the drules are applied, so they have no effect on the derivative of any \
exact form, which necessarily vanishes; e.g.,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dforms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[dforms]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[dforms]\)], "Input",
  InitializationCell->True],

Cell["(*but,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[forms]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[forms]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Generally, it is important to ensure consistency (closure) of the \
\"drules\", which is not verified automatically by the program; e.g.,*)\
\>", \
"Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(da[\[Xi]]\)], "Input",
  InitializationCell->True],

Cell["(*and differentiating without applying the \"drules\" gives,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but as required for consistency of the double derivative,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(applydrules[%]\)], "Input",
  InitializationCell->True],

Cell["(*Checking all of them*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[da[\[Xi]]] == da[da[\[Eta]]] == da[da[\[Zeta]]] == 0\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but again, this could be done in one step on the whole \
list;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[da[forms]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*This ensures that both double derivatives will vanish identically \
for all AVF expressions; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[d[avf2]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[da[avf2]]\)], "Input",
  InitializationCell->True],

Cell["\<\

 (*Generally, the use of \"drules\" is optional, but there is one situation \
in which they are mandatory, and is the reason for establishing a default \
value for them. The one place \"drules\" are required is for vector \
contractions, which are defined on all members of \"forms\", but not on their \
exterior derivative 2-forms. In the case of vector contraction, they are \
invoked automatically before doing the contraction; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec1\[SmallCircle]dforms\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Note that ",
  StyleBox["all",
    FontVariations->{"Underline"->True}],
  " the replacements that have been established as \"drules\" are applied in \
a contraction, not just those involving \"dforms\".*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\

(*In summary, establishing a set of \"drules\" is essential for most \
operations involving contractions, such as the Lie derivative of AVFs. In \
addition: they can be used to define anholonomic basis forms; to express \
derivatives of functions of coordinates in terms of an anholonomic basis; and \
to impose a group structure on the basis 1-forms using a set of Maurer-Cartan \
equations (as in \"newdrules\").\
\>", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n\n (*A\ TRANSFORMATION\ OF\ COORDINATES*) \)\)], "Input"],

Cell["\<\
(*Call the current scalars, 'cartesian', and add in a new set, \
'spherical';*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(cartesian = scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(spherical = {r, \[Theta], \[CurlyPhi]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[Join[cartesian, spherical]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The transformation from cartesian to spherical coordinates is expressed \
by a list of replacement rules, ",
  StyleBox["not",
    FontVariations->{"Underline"->True}],
  " assignments. Mathematica's Thread command is convenient for distributing \
the Rule symbol,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(trans = 
      Thread[cartesian -> {r\ Sin[\[Theta]]\ Cos[\[CurlyPhi]], 
            r\ Sin[\[Theta]] Sin[\[CurlyPhi]], r\ Cos[\[Theta]]}]\)], "Input",\

  InitializationCell->True],

Cell["\<\
(*and the transformation can be accomplished by ReplaceAll \
(/.).*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(cartesian /. trans\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The operator d[] works on a list of AVFs - not on a list of Rules \
- but the transformation of derivatives can be constructed quickly \
by;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dtrans = Thread[d[cartesian] -> d[\((cartesian /. trans)\)]]\)], "Input",\

  InitializationCell->True],

Cell["\<\
(*and all of these can be joined into a single list of \
transformation rules;*)\
\>", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(tospherical = Join[trans, dtrans]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[x\^2 + y\^2 /. tospherical]\)], "Input",
  InitializationCell->True],

Cell["(*For the volume form,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vol = dx\[Wedge]dy\[Wedge]dz\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vol /. tospherical\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The substitutions were made, but the expression needs to be \
simplified. Mathematica's Expand has no effect on wedge products,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Expand[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but the analogous AVF command does the required expansion of the \
wedge products,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell["(*after which Mathematica will simplify the coefficients,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  InitializationCell->True],

Cell["(*This could also be done with \"drules\".*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[dtrans]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[applydrules[vol]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n\n
     (*A\ TOY\ GEOMETRY\ \(PROBLEM\ --\)\ ALMOST\ TRIVIAL, \ 
      BUT\ NOT\ \(QUITE.\)*) \)\)], "Input",
  PageBreakAbove->True],

Cell["\<\
(*This problem shows how AVF and Mathematica commands work \
together, and further illustrates the use of \"drules\".*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "(*In cylindrical coordinates {r,\[Phi],z}, put r = R sin(\[Theta]) and z = \
",
  Cell[BoxData[
      \(TraditionalForm\`\@\((1\  - \ k)\)\)]],
  " R cos(\[Theta]), so that\n(1 - k) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(r\^2\),
            "TraditionalForm"], "+", \(z\^2\)}], TraditionalForm]]],
  "= (1 - k)",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  ",  a spheroid with equatorial radius R and polar radius ",
  Cell[BoxData[
      \(TraditionalForm\`\@\((1\  - \ k)\)\)]],
  "R ;\n(i.e., prolate for k < 0 , spherical for k=0, oblate for 0 < k < 1 , \
a disk of radius R for k = 1).*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The independent coordinates will be \[Theta] and \[Phi], and we \
also introduce three non-exact basis forms for later use .*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{\[Theta], \[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeforms[{\[Omega]\_1, \[Omega]\_2, \[Omega]\_3}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Previously, the variables r and z were in \"scalars\", but are \
not there now, so can be assigned values;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(r = R\ Sin[\[Theta]]\), "\n", 
    \(z = \(\@\((1 - k)\)\) R\ Cos[\[Theta]]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*Since k and R are not members of any fundamental list, they are \
treated as constant parameters.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(dr = d[r]\), "\n", 
    \(dz = d[z]\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*AVF knows that d\[Theta] and d\[Phi] are 1-forms, but Mathematica \
doesn't , so the Euclidean line element in cylindrical coordinates can be \
input as:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[
      dr\^2 + dz\^2 + \(r\^2\) d\[Phi]\^2 /. 
        Cos[\[Theta]]\^2 -> 1 - Sin[\[Theta]]\^2]\)], "Input",
  InitializationCell->True],

Cell["(*Using Mathematica's Collect[] command,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Collect[%, {d\[Theta]\^2, d\[Phi]\^2}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*showing the induced metric on the spheroid has orthonormal basis forms,  \
R",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{"1", "-", 
            RowBox[{"k", " ", 
              FormBox[\(sin\^2\),
                "TraditionalForm"], \((\[Theta])\)}]}]], TraditionalForm]]],
  "d\[Theta]  ,  \nR sin(\[Theta]) d\[Phi]  , which can be identified with \
the non-exact basis forms, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_2\)]],
  " . Here again \nwe use replacement rules, not assignments, which are \
forbidden for the members of \"forms\". \nIt's actually much more useful to \
express the relations this way, so that transformations between \nthe \
orthonormal and coordinate bases are easily made in both directions.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(tocoords = {\[Omega]\_1 -> 
          R \(\@\( 1 - k\ Sin[\[Theta]]^2\)\) 
            d\[Theta], \[Omega]\_\(\(2\)\(\ \)\) -> 
          R\ Sin[\[Theta]] d\[Phi]}\)], "Input",
  PageBreakAbove->True,
  InitializationCell->True],

Cell["\<\
(*The rules can be turned into equations to solve for the inverse \
transformation. Writing equations does not involve assignments, nor does \
their solution.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(eqns = tocoords /. Rule -> Equal\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(toortho = Flatten[Solve[eqns, dscalars]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*In a 2-dim space, the only independent connection form is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_12\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(\(3\)\(\ \)\)\)]],
  "is already in the \"forms\" \nlist, that symbol will be used for it \
temporarily. The Cartan structure equations,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\[Omega]\_i\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_ij\)]],
  "\[Wedge]",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_j\)]],
  "= 0 , \nthen can be expressed by the replacement rules: *) "
}], "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(structure = {d\[Omega]\_1 -> \[Omega]\_2\[Wedge]\[Omega]\_3, 
        d\[Omega]\_2 -> \[Omega]\_3\[Wedge]\[Omega]\_1}\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The transformations \"toortho\" can also be entered as \
\"drules\", so that everything,
including derivatives of functions, will be converted automatically to the \
orthobasis.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[Join[structure, toortho]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Because no drule has been established for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_3\)]],
  ", these \"drules\" are not properly closed. Imposing closure can be used \
to determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_3\)]],
  "; i.e., for consistency the following conditions must vanish,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(conditions = da[da[scalars]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Vanishing of the first condition requires ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(\(3\)\(\ \)\)\)]],
  "proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_2\)]],
  "with no component on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  ". \nSo we can safely factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " out of the second condition, and equate the result to zero.*) "
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(factor[\[Omega]\_1, conditions[\([2]\)]] == 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(soln = Flatten[Solve[%, \[Omega]\_3]]\)], "Input",
  InitializationCell->True],

Cell["(*Put this into \"drules\":*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(newdrules = expand[drules /. soln]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and the obvious fact that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  " is closed appears explicitly. Now establish these as the \"drules\",*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[newdrules]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note: the last two statements could be combined into one (without \
defining \"newdrules\"), but \"drules\" is Protected, so it can't be \
accomplished just by assignment without using \"makedrules[].*)\
\>", "Input",\

  FontFamily->"Times"],

Cell["(*Checking for consistency:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[da[scalars]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[da[forms]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n\n(*Set the connection form equal to the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_3\)]],
  ", and find the curvature 2-form\n expressed in orthobasis:*)"
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Omega]\_12 = \[Omega]\_3 /. soln\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[CapitalOmega]\_12 = da[\[Omega]\_12]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[CapitalOmega]\_12 = Simplify[%]\)], "Input",
  InitializationCell->True],

Cell["(*The same quantity in the coordinate basis:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalOmega]\_\[Theta]\[Phi] = 
      Simplify[expand[\[CapitalOmega]\_12 /. tocoords], 
        Trig -> False]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Interpretation of the following special values (as products of \
the Gaussian curvatures) is much simpler in the orthonormal basis than in the \
coordinate basis.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["(*At the poles:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalOmega]\_12 /. \[Theta] -> 0\)], "Input",
  InitializationCell->True],

Cell["(*At the equator:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalOmega]\_12 /. \[Theta] -> Pi/2\)], "Input",
  InitializationCell->True],

Cell["(*And for a sphere:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalOmega]\_12 /. k -> 0\)], "Input",
  InitializationCell->True],

Cell["(*In 2-dim the Bianchi identity is trivial:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[\[CapitalOmega]\_12]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n\n(*The surface element in the orthonormal basis ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(is\ \ \[Omega]\_1\),
            "TraditionalForm"], "\[Wedge]", \(\[Omega]\_2\)}], 
        TraditionalForm]]],
  ", while in the coordinate basis:*)"
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(expand[\[Omega]\_1\[Wedge]\[Omega]\_2 /. tocoords]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The area of a polar cap, where \"pa\" is the polar angle or \
colatitude, is:*)\
\>", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(polarcap = 
      Integrate[
        R\^2\ Sin[\[Theta]]\ \@\(1 - k\ Sin[\[Theta]]\^2\), {\[Theta], 0, 
          pa}, {\[Phi], 0, 2\ Pi}]\)], "Input",
  InitializationCell->True],

Cell["(*and this gives the familiar result for a sphere;*) ", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[Limit[polarcap, k -> 0]]\)], "Input",
  InitializationCell->True],

Cell["(*The total surface area for any spheroid is,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(area = Simplify[polarcap /. pa -> Pi]\)], "Input",
  InitializationCell->True],

Cell["(*For the sphere:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Limit[area, k -> 0]\)], "Input",
  InitializationCell->True],

Cell["(*For the flat disk:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Limit[area, k -> 1]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*In this simple 2-dim. case, the Hodge star operation is easily defined in \
the orthonormal basis.*) \
\>", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(toduals = {\[Omega]\_1 -> \[Omega]\_2, \[Omega]\_2 -> \(-\[Omega]\_1\)}\
\)], "Input",
  InitializationCell->True],

Cell["\<\
(*For a function, \[Psi][\[Theta],\[Phi]} , with exterior \
derivative in the coordinate basis,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[\[Psi][\[Theta], \[Phi]]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*the  *d[\[Psi]]  operation is given by,*)\
\>", "Input",
  PageBreakAbove->Automatic,
  FontFamily->"Times"],

Cell[BoxData[
    \(da[\[Psi][\[Theta], \[Phi]]] /. toduals\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and the Laplacian on the spheroid, d*d[\[Psi]] , is the factor of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\[Wedge]\[Omega]\_\(\(2\)\(\ \)\)\)]],
  "in the next expression,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[da[%]]\)], "Input",
  InitializationCell->True],

Cell["(*which becomes the usual expression for a sphere,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(% /. k -> 0\)], "Input",
  InitializationCell->True],

Cell["\<\


(*Elapsed time since the first statement.*)\
\>", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \( (*NOTE1*) \)], "Input"],

Cell["\<\
(*If you return to the beginning of this program and attempt to \
re-execute, the program will cause an Interrupt at the \"makescalars\" \
command, and must be Aborted. The reason is that the coordinates r and z (and \
their derivatives) were given assigned values in the \"Toy Geometry\" \
section, and \"makescalars\" won't accept expressions for \"scalars\". You \
can try it just to see what happens. Doing \"Quit Kernel\" (or else the \
following statement) is required to re-execute successfully.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[r, z, dr, dz]\)], "Input"],

Cell["\<\
(*Furthermore, because \"scalars\", \"forms\", and \"drules\" have \
been changed frequently throughout the program, it's not possible to return \
to a particular statement and re-execute it, unless those lists are first \
restored to their appropriate values for that statement with the respective \
\"make\" commands.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \( (*NOTE2*) \)], "Input"],

Cell["\<\
(*Section VII of AVF_Introduction.nb comprises a glossary of AVF \
and CAV variables and functions. Typing the variable \"names\" within a \
program returns a simple list of their names; i.e.,*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(names\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{629, 574},
WindowMargins->{{4, Automatic}, {Automatic, 3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@gZlT0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 188, 5, 43, "Input"],
Cell[1945, 58, 524, 10, 108, "Input"],
Cell[2472, 70, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[2549, 74, 104, 2, 43, "Input"],
Cell[2656, 78, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[2742, 82, 117, 4, 28, "Input"],
Cell[2862, 88, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[2934, 92, 95, 1, 28, "Input"],
Cell[3032, 95, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3101, 99, 131, 4, 28, "Input"],
Cell[3235, 105, 96, 2, 27, "Input",
  InitializationCell->True],
Cell[3334, 109, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[3404, 113, 203, 5, 44, "Input"],
Cell[3610, 120, 130, 4, 28, "Input"],
Cell[3743, 126, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[3815, 130, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[3886, 134, 319, 8, 60, "Input"],
Cell[4208, 144, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[4310, 148, 606, 10, 108, "Input"],
Cell[4919, 160, 155, 6, 44, "Input"],
Cell[5077, 168, 295, 6, 60, "Input"],
Cell[5375, 176, 199, 4, 27, "Input",
  InitializationCell->True],
Cell[5577, 182, 208, 7, 28, "Input"],
Cell[5788, 191, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[5872, 195, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[5943, 199, 98, 1, 28, "Input"],
Cell[6044, 202, 91, 3, 27, "Input",
  PageBreakAbove->False,
  InitializationCell->True],
Cell[6138, 207, 203, 5, 44, "Input"],
Cell[6344, 214, 147, 6, 44, "Input"],
Cell[6494, 222, 397, 9, 60, "Input"],
Cell[6894, 233, 254, 5, 75, "Input",
  InitializationCell->True],
Cell[7151, 240, 183, 6, 28, "Input"],
Cell[7337, 248, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[7432, 252, 217, 5, 44, "Input"],
Cell[7652, 259, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7724, 263, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[7808, 267, 147, 4, 28, "Input"],
Cell[7958, 273, 97, 2, 59, "Input",
  PageBreakAbove->True],
Cell[8058, 277, 315, 6, 60, "Input"],
Cell[8376, 285, 117, 2, 29, "Input",
  InitializationCell->True],
Cell[8496, 289, 114, 2, 27, "Input",
  InitializationCell->True],
Cell[8613, 293, 92, 3, 43, "Input",
  InitializationCell->True],
Cell[8708, 298, 379, 9, 60, "Input"],
Cell[9090, 309, 80, 1, 59, "Input"],
Cell[9173, 312, 137, 6, 28, "Input"],
Cell[9313, 320, 359, 7, 60, "Input"],
Cell[9675, 329, 207, 6, 28, "Input"],
Cell[9885, 337, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[9992, 341, 123, 4, 28, "Input"],
Cell[10118, 347, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[10194, 351, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[10277, 355, 144, 4, 28, "Input"],
Cell[10424, 361, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[10561, 366, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[10654, 370, 144, 6, 44, "Input"],
Cell[10801, 378, 194, 5, 44, "Input",
  PageBreakAbove->True],
Cell[10998, 385, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[11074, 389, 97, 1, 28, "Input"],
Cell[11174, 392, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[11251, 396, 288, 7, 44, "Input"],
Cell[11542, 405, 96, 2, 27, "Input",
  InitializationCell->True],
Cell[11641, 409, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[11717, 413, 148, 4, 28, "Input"],
Cell[11868, 419, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[11953, 423, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[12042, 427, 230, 10, 44, "Input",
  PageBreakAbove->True],
Cell[12275, 439, 489, 8, 76, "Input"],
Cell[12767, 449, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[12835, 453, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[12903, 457, 207, 5, 44, "Input"],
Cell[13113, 464, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[13182, 468, 96, 2, 27, "Input",
  InitializationCell->True],
Cell[13281, 472, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[13349, 476, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[13435, 480, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[13518, 484, 80, 1, 28, "Input"],
Cell[13601, 487, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[13705, 491, 99, 2, 28, "Input",
  PageBreakAbove->Automatic],
Cell[13807, 495, 115, 2, 27, "Input",
  InitializationCell->True],
Cell[13925, 499, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[13999, 503, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[14082, 507, 493, 9, 76, "Input"],
Cell[14578, 518, 139, 4, 28, "Input"],
Cell[14720, 524, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[14806, 528, 74, 1, 28, "Input"],
Cell[14883, 531, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[14969, 535, 99, 1, 28, "Input"],
Cell[15071, 538, 141, 6, 44, "Input"],
Cell[15215, 546, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[15283, 550, 144, 4, 28, "Input"],
Cell[15430, 556, 88, 2, 27, "Input",
  InitializationCell->True],
Cell[15521, 560, 254, 7, 44, "Input"],
Cell[15778, 569, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[15867, 573, 227, 5, 44, "Input"],
Cell[16097, 580, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[16170, 584, 149, 4, 28, "Input"],
Cell[16322, 590, 276, 6, 75, "Input",
  InitializationCell->True],
Cell[16601, 598, 56, 1, 28, "Input"],
Cell[16660, 601, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[16761, 605, 295, 11, 44, "Input"],
Cell[17059, 618, 338, 7, 60, "Input"],
Cell[17400, 627, 77, 2, 27, "Input",
  InitializationCell->True],
Cell[17480, 631, 256, 6, 44, "Input"],
Cell[17739, 639, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[17812, 643, 365, 7, 60, "Input"],
Cell[18180, 652, 333, 7, 60, "Input"],
Cell[18516, 661, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[18600, 665, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[18673, 669, 383, 7, 76, "Input"],
Cell[19059, 678, 114, 2, 27, "Input",
  InitializationCell->True],
Cell[19176, 682, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[19249, 686, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[19354, 690, 89, 1, 59, "Input"],
Cell[19446, 693, 125, 4, 28, "Input"],
Cell[19574, 699, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[19642, 703, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[19713, 707, 200, 5, 44, "Input"],
Cell[19916, 714, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[19987, 718, 94, 1, 28, "Input"],
Cell[20084, 721, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[20163, 725, 75, 1, 28, "Input"],
Cell[20241, 728, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[20315, 732, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[20383, 736, 424, 8, 76, "Input"],
Cell[20810, 746, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[20926, 750, 312, 7, 76, "Input"],
Cell[21241, 759, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[21360, 763, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[21431, 767, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[21517, 771, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[21585, 775, 100, 1, 28, "Input"],
Cell[21688, 778, 77, 2, 27, "Input",
  InitializationCell->True],
Cell[21768, 782, 146, 6, 60, "Input"],
Cell[21917, 790, 839, 14, 156, "Input"],
Cell[22759, 806, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[22830, 810, 222, 5, 44, "Input"],
Cell[23055, 817, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[23125, 821, 121, 2, 28, "Input",
  PageBreakAbove->True],
Cell[23249, 825, 190, 4, 27, "Input",
  InitializationCell->True],
Cell[23442, 831, 166, 5, 28, "Input",
  PageBreakAbove->Automatic],
Cell[23611, 838, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[23696, 842, 224, 5, 44, "Input"],
Cell[23923, 849, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[23994, 853, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[24072, 857, 333, 6, 60, "Input"],
Cell[24408, 865, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[24486, 869, 56, 1, 28, "Input"],
Cell[24545, 872, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[24629, 876, 100, 2, 28, "Input",
  PageBreakAbove->Automatic],
Cell[24732, 880, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[24817, 884, 262, 6, 44, "Input",
  PageBreakAbove->Automatic],
Cell[25082, 892, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[25163, 896, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[25241, 900, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[25323, 904, 297, 7, 44, "Input"],
Cell[25623, 913, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[25693, 917, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[25766, 921, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[25840, 925, 48, 1, 28, "Input"],
Cell[25891, 928, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[25960, 932, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[26032, 936, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[26105, 940, 220, 6, 44, "Input",
  PageBreakAbove->Automatic],
Cell[26328, 948, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[26401, 952, 102, 1, 28, "Input"],
Cell[26506, 955, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[26574, 959, 111, 4, 28, "Input"],
Cell[26688, 965, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[26766, 969, 64, 1, 28, "Input"],
Cell[26833, 972, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[26952, 976, 114, 4, 28, "Input"],
Cell[27069, 982, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[27146, 986, 150, 4, 28, "Input"],
Cell[27299, 992, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[27373, 996, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[27449, 1000, 487, 9, 92, "Input"],
Cell[27939, 1011, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[28027, 1015, 263, 7, 44, "Input"],
Cell[28293, 1024, 487, 10, 92, "Input",
  PageBreakAbove->True],
Cell[28783, 1036, 81, 1, 59, "Input"],
Cell[28867, 1039, 127, 4, 28, "Input"],
Cell[28997, 1045, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[29080, 1049, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[29182, 1053, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[29285, 1057, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[29357, 1061, 324, 8, 44, "Input"],
Cell[29684, 1071, 201, 5, 27, "Input",
  InitializationCell->True],
Cell[29888, 1078, 116, 4, 28, "Input"],
Cell[30007, 1084, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[30089, 1088, 192, 5, 44, "Input"],
Cell[30284, 1095, 123, 3, 27, "Input",
  InitializationCell->True],
Cell[30410, 1100, 157, 5, 28, "Input",
  PageBreakAbove->Automatic],
Cell[30570, 1107, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[30667, 1111, 97, 2, 31, "Input",
  InitializationCell->True],
Cell[30767, 1115, 64, 1, 28, "Input"],
Cell[30834, 1118, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[30926, 1122, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[31008, 1126, 181, 5, 44, "Input"],
Cell[31192, 1133, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[31265, 1137, 134, 4, 28, "Input"],
Cell[31402, 1143, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[31475, 1147, 99, 1, 28, "Input"],
Cell[31577, 1150, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[31652, 1154, 84, 1, 28, "Input"],
Cell[31739, 1157, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[31821, 1161, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[31911, 1165, 157, 4, 59, "Input",
  PageBreakAbove->True],
Cell[32071, 1171, 167, 4, 44, "Input"],
Cell[32241, 1177, 689, 20, 62, "Input"],
Cell[32933, 1199, 176, 4, 44, "Input"],
Cell[33112, 1205, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[33207, 1209, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[33321, 1213, 158, 4, 28, "Input"],
Cell[33482, 1219, 138, 3, 47, "Input",
  InitializationCell->True],
Cell[33623, 1224, 149, 4, 28, "Input"],
Cell[33775, 1230, 98, 3, 43, "Input",
  InitializationCell->True],
Cell[33876, 1235, 205, 5, 44, "Input"],
Cell[34084, 1242, 166, 4, 31, "Input",
  InitializationCell->True],
Cell[34253, 1248, 82, 1, 28, "Input"],
Cell[34338, 1251, 99, 2, 31, "Input",
  InitializationCell->True],
Cell[34440, 1255, 885, 22, 98, "Input"],
Cell[35328, 1279, 248, 6, 33, "Input",
  PageBreakAbove->True,
  InitializationCell->True],
Cell[35579, 1287, 208, 5, 44, "Input"],
Cell[35790, 1294, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[35886, 1298, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[35990, 1302, 675, 20, 60, "Input",
  PageBreakAbove->Automatic],
Cell[36668, 1324, 178, 3, 27, "Input",
  InitializationCell->True],
Cell[36849, 1329, 229, 6, 44, "Input"],
Cell[37081, 1337, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[37181, 1341, 379, 10, 44, "Input"],
Cell[37563, 1353, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[37655, 1357, 522, 16, 44, "Input",
  PageBreakAbove->True],
Cell[38180, 1375, 106, 2, 27, "Input",
  InitializationCell->True],
Cell[38289, 1379, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[38390, 1383, 69, 1, 28, "Input"],
Cell[38462, 1386, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[38560, 1390, 220, 6, 28, "Input"],
Cell[38783, 1398, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[38868, 1402, 254, 6, 44, "Input"],
Cell[39125, 1410, 69, 1, 28, "Input"],
Cell[39197, 1413, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[39276, 1417, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[39353, 1421, 260, 7, 76, "Input",
  PageBreakAbove->True],
Cell[39616, 1430, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[39714, 1434, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[39816, 1438, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[39913, 1442, 86, 1, 28, "Input"],
Cell[40002, 1445, 175, 4, 27, "Input",
  InitializationCell->True],
Cell[40180, 1451, 214, 5, 44, "Input"],
Cell[40397, 1458, 57, 1, 28, "Input"],
Cell[40457, 1461, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[40557, 1465, 59, 1, 28, "Input"],
Cell[40619, 1468, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[40722, 1472, 61, 1, 28, "Input"],
Cell[40786, 1475, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[40879, 1479, 85, 1, 28, "Input"],
Cell[40967, 1482, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[41054, 1486, 352, 11, 60, "Input",
  PageBreakAbove->True],
Cell[41409, 1499, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[41523, 1503, 158, 5, 28, "Input",
  PageBreakAbove->Automatic],
Cell[41684, 1510, 199, 5, 36, "Input",
  InitializationCell->True],
Cell[41886, 1517, 93, 1, 28, "Input"],
Cell[41982, 1520, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[42083, 1524, 87, 1, 28, "Input"],
Cell[42173, 1527, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[42274, 1531, 59, 1, 28, "Input"],
Cell[42336, 1534, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[42419, 1538, 62, 1, 28, "Input"],
Cell[42484, 1541, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[42567, 1545, 176, 6, 44, "Input",
  PageBreakAbove->True],
Cell[42746, 1553, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[42883, 1558, 145, 4, 28, "Input"],
Cell[43031, 1564, 88, 2, 27, "Input",
  InitializationCell->True],
Cell[43122, 1568, 120, 4, 28, "Input",
  PageBreakAbove->Automatic],
Cell[43245, 1574, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[43348, 1578, 246, 6, 28, "Input"],
Cell[43597, 1586, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[43676, 1590, 92, 1, 28, "Input"],
Cell[43771, 1593, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[43846, 1597, 117, 6, 60, "Input",
  PageBreakAbove->True],
Cell[43966, 1605, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[44037, 1609, 44, 1, 27, "Input"],
Cell[44084, 1612, 552, 9, 92, "Input"],
Cell[44639, 1623, 52, 1, 27, "Input"],
Cell[44694, 1626, 369, 7, 60, "Input"],
Cell[45066, 1635, 44, 1, 27, "Input"],
Cell[45113, 1638, 243, 5, 44, "Input"],
Cell[45359, 1645, 66, 2, 27, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

