(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11079,        255]*)
(*NotebookOutlinePosition[     11953,        283]*)
(*  CellTagsIndexPosition[     11909,        279]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(dim = Length[signature]; \nDo[sig[i] = signature[\([i]\)], {i, dim}]; \n
    makeforms[Table[\[Theta]\_i, {i, dim}]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(b2s = 
      Flatten[Table[
          b2[i$1, i$2] = \[Theta]\_i\[Wedge]\[Theta]\_j, {i$1, dim - 1}, {
            i$2, i$1 + 1, dim}]]; \n
    toB2s = Flatten[
        Table[\[Theta]\_i$1\[Wedge]\[Theta]\_i$2 -> B2[i$1, i$2], {i$1, 
            dim - 1}, {i$2, i$1 + 1, dim}]]; \n
    tob2s = Flatten[
        Table[B2[i$1, i$2] -> b2[i$1, i$2], {i$1, dim - 1}, {i$2, i$1 + 1, 
            dim}]]; \n
    riccis = Flatten[
        Table[\[CapitalGamma]\_\(i$1, i$2, i$3\), {i$1, dim}, {i$2, 
            dim - 1}, {i$3, i$2 + 1, dim}]]; \n
    Do[\[CapitalGamma]\_\(i$1, i$2, i$3\) = 
        \(-\[CapitalGamma]\_\(i$1, i$3, i$2\)\), {i$1, dim}, {i$3, dim - 1}, {
        i$2, i$3 + 1, dim}]; 
    Do[\[CapitalGamma]\_\(i$1, i$3, i$3\) = 0, {i$1, dim}, {i$3, dim}]; 
    Do[x\[Omega]\_\(i$1, i$2\) = 
        \(-Sum[sig[i$3] \(\[CapitalGamma]\_\(i$3, i$1, i$2\)\) 
              \[Theta]\_i$3, {i$3, dim}]\); 
      x\[Omega]\_\(i$2, i$1\) = \(-x\[Omega]\_\(i$1, i$2\)\), {i$1, 
        dim - 1}, {i$2, i$1 + 1, dim}]; 
    Do[x\[Omega]\_\(i$1, i$1\) = 0, {i$1, dim}]; \n
    Rms = Flatten[
        Table[R\_\(i$1, i$2, i$3, i$4\), {i$1, dim - 1}, {i$2, i$1 + 1, 
            dim}, {i$3, dim - 1}, {i$4, i$3 + 1, dim}]]; \n
    Rcs = Flatten[Table[R\_\(i$1, i$2\), {i$1, dim}, {i$2, i$1, dim}]]; \n
    stress = {
        \[Rho] -> 
          \((R\_\(1, 1\) + R\_\(2, 2\) + R\_\(3, 3\) + R\_\(4, 4\))\)/4, 
        p -> R\_\(4, 4\)/4 - 
            \((R\_\(1, 1\) + R\_\(2, 2\) + R\_\(3, 3\))\)/12, 
        \[Mu] -> R\_\(4, 4\), t\_1 -> R\_\(1, 4\)/2, t\_2 -> R\_\(2, 4\)/2, 
        t\_3 -> R\_\(3, 4\)/2, 
        M\_\(1, 1\) -> 
          \(-R\_\(1, 1\)\)/3 + \((R\_\(2, 2\) + R\_\(3, 3\))\)/6, 
        M\_\(2, 2\) -> 
          \(-R\_\(2, 2\)\)/3 + \((R\_\(1, 1\) + R\_\(3, 3\))\)/6, 
        M\_\(3, 3\) -> 
          \(-R\_\(3, 3\)\)/3 + \((R\_\(2, 2\) + R\_\(1, 1\))\)/6, 
        M\_\(1, 2\) -> \(-R\_\(1, 2\)\)/2, M\_\(1, 3\) -> \(-R\_\(1, 3\)\)/2, 
        M\_\(2, 3\) -> \(-R\_\(2, 3\)\)/2}; \n
    AB = {A\_\(1, 1\) -> C\_\(1, 4, 1, 4\), A\_\(2, 2\) -> C\_\(2, 4, 2, 4\), 
        A\_\(3, 3\) -> C\_\(3, 4, 3, 4\), A\_\(1, 2\) -> C\_\(1, 4, 2, 4\), 
        A\_\(1, 3\) -> C\_\(1, 4, 3, 4\), A\_\(2, 3\) -> C\_\(2, 4, 3, 4\), 
        B\_\(1, 1\) -> C\_\(1, 4, 2, 3\), 
        B\_\(2, 2\) -> \(-C\_\(1, 3, 2, 4\)\), 
        B\_\(3, 3\) -> C\_\(1, 2, 3, 4\), 
        B\_\(1, 2\) -> \(-C\_\(1, 3, 1, 4\)\), 
        B\_\(1, 3\) -> C\_\(1, 2, 1, 4\), B\_\(2, 3\) -> C\_\(1, 2, 2, 4\)}; 
    \ndyadics = {a\_1 \[Rule] \(-\[CapitalGamma]\_\(4, 1, 4\)\), 
        a\_2 \[Rule] \(-\[CapitalGamma]\_\(4, 2, 4\)\), 
        a\_3 \[Rule] \(-\[CapitalGamma]\_\(4, 3, 4\)\), 
        \[CapitalOmega]\_1 \[Rule] 
          \((\[CapitalGamma]\_\(2, 3, 4\) - \[CapitalGamma]\_\(3, 2, 4\))\)/
            2, \[CapitalOmega]\_2 \[Rule] \ 
          \((\(-\[CapitalGamma]\_\(1, 3, 4\)\) + \[CapitalGamma]\_\(3, 1, 4\))
              \)/2, \[CapitalOmega]\_3 \[Rule] 
          \((\[CapitalGamma]\_\(1, 2, 4\) - \[CapitalGamma]\_\(2, 1, 4\))\)/
            2, S\_\(1, 1\) \[Rule] \[CapitalGamma]\_\(1, 1, 4\), 
        S\_\(2, 2\) \[Rule] \[CapitalGamma]\_\(2, 2, 4\), 
        S\_\(3, 3\) \[Rule] \[CapitalGamma]\_\(3, 3, 4\), 
        S\_\(1, 2\) \[Rule] \ 
          \((\[CapitalGamma]\_\(1, 2, 4\) + \[CapitalGamma]\_\(2, 1, 4\))\)/
            2, S\_\(1, 3\) \[Rule] \ 
          \((\[CapitalGamma]\_\(1, 3, 4\) + \[CapitalGamma]\_\(3, 1, 4\))\)/
            2, S\_\(2, 3\) \[Rule] 
          \((\[CapitalGamma]\_\(2, 3, 4\) + \[CapitalGamma]\_\(3, 2, 4\))\)/
            2, TrS -> 
          \[CapitalGamma]\_\(1, 1, 4\) + \[CapitalGamma]\_\(2, 2, 4\) + 
            \[CapitalGamma]\_\(3, 3, 4\)}; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Q = 
      Table[If[j > i - 1, A\_\(i, j\) + I\ B\_\(i, j\), 
          A\_\(j, i\) + I\ B\_\(j, i\)], {i, 3}, {j, 3}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; 
    Print["\<The inverse transformation back to orthoframe:'toortho'\>"]; \n
    toortho = 
      Simplify[Flatten[
          Solve[tocoords /. Rule -> Equal, prune[dscalars, tocoords]]]]; \n
    If[output, Print["\<toortho = \>", toortho]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; Print["\<Exterior derivatives of orthoframe:'dortho'\>"]; \n
    dortho = Table[
        d\[Theta]\_i$1 -> 
          Simplify[expand[d[\[Theta]\_i$1 /. tocoords] /. toortho]], {i$1, 
          dim}]; \nIf[output, Print["\<dortho = \>", dortho]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; 
    Print["\<The general matrix of connection 1-forms:'generalomegas'\>"]; \n
    generalomegas = 
      Flatten[Table[
          \[Omega]\_\(i$1, i$2\) -> x\[Omega]\_\(i$1, i$2\), {i$1, dim - 1}, {
            i$2, i$1 + 1, dim}]]; \n
    If[output, Print["\<generalomegas = \>", generalomegas]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; 
    Print["\<Ricci rotation coefficients for orthoframe:'rotationcomps'\>"]; 
    \ntorsion = 
      Table[\((dforms[\([i$1]\)] /. dortho)\) + 
            Sum[sig[i$3] x\[Omega]\_\(i$1, i$3\)**\[Theta]\_i$3, {i$3, 
                dim}], {i$1, dim}] /. toB2s; \n
    torsions = 
      Flatten[Table[
          Coefficient[torsion[\([i$1]\)], B2[i$2, i$3]], {i$1, dim}, {i$2, 
            dim - 1}, {i$3, i$2 + 1, dim}]]; \n
    rotationcomps = Flatten[Solve[setzero[torsions], riccis]]; \n
    rotationcomps = Simplify[rotationcomps]; \n
    If[output, Print["\<rotationcomps = \>", rotationcomps]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; Print["\<The solved matrix of connection 1-forms:'omegas'\>"]; 
    \nomegas = Simplify[generalomegas /. rotationcomps]; \n
    If[output, Print["\<omegas = \>", omegas]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; 
    Print["\<Orthonormal components of the Riemann tensor:'riemanncomps'\>"]
      \ ; \nDo[x\[Omega]\_\(i$1, i$2\) = 
        \((x\[Omega]\_\(i$1, i$2\) /. rotationcomps)\), {i$1, dim}, {i$2, 
        dim}]; \nriemann2 = 
      Flatten[Table[
            Sum[sig[i$3]\ sig[i$4] \(R\_\(i$1, i$2, i$3, i$4\)\) 
                  B2[i$3, i$4], {i$3, dim - 1}, {i$4, i$3 + 1, dim}] - 
              expand[\(d[x\[Omega]\_\(i$1, i$2\)] /. dortho\) /. toortho] - 
              Sum[sig[i$5] x\[Omega]\_\(i$1, i$5\)**x\[Omega]\_\(i$5, i$2\), {
                  i$5, dim}], {i$1, dim - 1}, {i$2, i$1 + 1, dim}]] /. toB2s; 
    \nriemanns = 
      Flatten[Table[
          Coefficient[riemann2[\([i$1]\)], B2[i$2, i$3]], {i$1, 
            Length[riemann2]}, {i$2, dim - 1}, {i$3, i$2 + 1, dim}]]; \n
    riemanncomps = Flatten[Solve[setzero[riemanns], Rms]]; \n
    riemanncomps = 
      Simplify[riemanncomps
           /. {Cos[am$_]^2 -> 1 - Sin[am$]^2, Cot[an$_]^2 -> Csc[an$]^2 - 1}, 
        Trig -> False]; \n
    If[output, Print["\<riemanncomps = \>", riemanncomps]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; 
    Print["\<Orthonormal components of the Ricci tensor:'riccicomps'\>"]\ ; \n
    fx$ := \((fc$ = Signature[{i$3, i$1}] Signature[{i$3, i$2}]; 
        id$ = Flatten[Join[Sort[{i$3, i$1}], Sort[{i$3, i$2}]]])\); \n
    riccicomps := 
      Flatten[Table[
          R\_\(i$1, i$2\) -> 
            Sum[fx$; 
              fc$\ sig[i$3]\ 
                R\_\(id$[\([1]\)], id$[\([2]\)], id$[\([3]\)], 
                  id$[\([4]\)]\), {i$3, dim}], {i$1, dim}, {i$2, i$1, dim}]]; 
    \nriccicomps = Simplify[riccicomps /. riemanncomps, Trig -> False]; 
    Do[R\_\(i$2, i$1\) = R\_\(i$1, i$2\), {i$1, dim}, {i$2, i$1, dim}]; \n
    If[output, Print["\<riccicomps = \>", riccicomps]]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print[]; Print["\<The Ricci scalar:'ricciscalar'\>"]\ ; \n
    ricciscalar = 
      Simplify[{R\_s -> Sum[sig[i$3]\ R\_\(i$3, i$3\), {i$3, dim}]} /. 
          riccicomps, Trig -> False]; \n
    If[output, Print["\<ricciscalar = \>", ricciscalar]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(If[dim > 2, Print[]; 
      Print["\<Orthonormal components of the Weyl tensor:'weylcomps'\>"]\ ; 
      gx$s[i$5_, i$6_] := If[i$5 == i$6, sig[i$5], 0]; 
      weylcomps := 
        Flatten[Table[
            C\_\(i$1, i$2, i$3, i$4\) -> 
              R\_\(i$1, i$2, i$3, i$4\) - 
                \((gx$s[i$2, i$4]\ R\_\(i$1, i$3\))\)/\((dim - 2)\) + 
                \((gx$s[i$1, i$4]\ R\_\(i$2, i$3\))\)/\((dim - 2)\) - 
                \((gx$s[i$1, i$3]\ R\_\(i$2, i$4\))\)/\((dim - 2)\) + 
                \((gx$s[i$2, i$3]\ R\_\(i$1, i$4\))\)/\((dim - 2)\) + 
                \((gx$s[i$1, i$3] gx$s[i$2, i$4] - 
                      gx$s[i$1, i$4] gx$s[i$2, i$3])\) 
                  \(R\_s/\((dim - 1)\)\)/\((dim - 2)\), {i$1, dim - 1}, {i$2, 
              i$1 + 1, dim}, {i$3, i$1, dim - 1}, {i$4, i$3 + 1, dim}]]; \n
      weylcomps = 
        Simplify[
          \(\(weylcomps /. riemanncomps\) /. riccicomps\) /. ricciscalar, 
          Trig -> False]; \n
      If[output, Print["\<weylcomps = \>", weylcomps]]]; \)\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{520, 509},
WindowMargins->{{154, Automatic}, {Automatic, 31}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 179, 3, 57, "Input",
  InitializationCell->True],
Cell[1891, 54, 3764, 72, 542, "Input",
  InitializationCell->True],
Cell[5658, 128, 179, 4, 44, "Input",
  InitializationCell->True],
Cell[5840, 134, 313, 7, 101, "Input",
  InitializationCell->True],
Cell[6156, 143, 317, 6, 90, "Input",
  InitializationCell->True],
Cell[6476, 151, 369, 8, 88, "Input",
  InitializationCell->True],
Cell[6848, 161, 672, 14, 193, "Input",
  InitializationCell->True],
Cell[7523, 177, 242, 4, 71, "Input",
  InitializationCell->True],
Cell[7768, 183, 1141, 22, 289, "Input",
  InitializationCell->True],
Cell[8912, 207, 756, 15, 198, "Input",
  InitializationCell->True],
Cell[9671, 224, 308, 6, 88, "Input",
  InitializationCell->True],
Cell[9982, 232, 1093, 21, 277, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

